@@ -10,8 +10,9 @@
 
 BEGIN { $| = 1; print "1..1\n"; }
 END {print "not ok 1\n" unless $loaded;}
+use lib qw( .. );
 use Pat::Logger;
-use Pat::General;
+use Time::localtime;
 
 $loaded = 1;
 print "ok 1\n";
